==> v1.15.3.tar.gz: le-chat-php/lang_ru.php <==
<?php
/*
* LE CHAT-PHP - a PHP Chat based on LE CHAT - Russian translation
*
* Copyright (C) 2015-2016 Daniel Winzen <d@winzen4.de>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//Native language name: Русский
$T=array(
	'nodb' => 'Нет соединения с базой данных!',
	'nodbsetup' => 'Нет соединения с базой данных, пожалуйста, создайте базу данных и измените сценарий, чтобы использовать правильную базу данных с заданными именем пользователя и паролем!',
	'changelang' => 'Изменить язык:',
	'expire' => 'Недействительная/с истекшим сроком сессия',
	'kicked' => 'Забанен!',
	'invalnick' => 'Недействительный ник (%d символов максимум, никакие специальные разрешенные символы)',
	'invalpass' => 'Неверный пароль (по крайней мере %d символов)',
	'noconfirm' => 'Подтверждение пароля не совпадает!',
	'incorregex' => 'Неправильное регулярное выражение!',
	'bottom' => 'Вниз',
	'top' => 'Вверх',
	'choose' => '(выбрать)',
	'setup' => 'Установка чата',
	'init' => 'Начальная установка',
	'sulogin' => 'Вход для суперадминистратора',
	'sunick' => 'Ник суперадминистратора:',
	'supass' => 'Пароль суперадминистратора:',
	'suconfirm' => 'Подтверждение пароля:',
	'susuccess' => 'Успешно зарегистрирован!',
	'initbtn' => 'Инициализация чата',
	'initdbexist' => 'Таблицы базы данных уже существуют! Чтобы продолжить, вы должны сначала удалить эти таблицы вручную.',
	'initsuexist' => 'Суперадминистратор уже существует!',
	'initgosetup' => 'Перейти к странице установки',
	'captcha' => 'Captcha',
	'enabled' => 'Включен',
	'onlyguests' => 'Только для гостей',
	'disabled' => 'Выключен',
	'simple' => 'Простая',
	'moderate' => 'Умеренная',
	'extreme' => 'Сильная',
	'nick' => 'Ник:',
	'pass' => 'Пароль:',
	'globalloginpass' => 'Глобальный пароль:',
	'login' => 'Войти',
	'dbupdate' => 'База данных успешно обновлена!',
	'sysmessages' => 'Системные сообщения',
	'msgenter' => 'Вход',
	'msgexit' => 'Выход',
	'msgmemreg' => 'Зарегистрированные',
	'msgsureg' => 'Заявитель зарегистрирован',
	'msgkick' => 'Забаненые',
	'msgmultikick' => 'Многократно забаненые',
	'msgallkick' => 'Все забаненые',
	'msgclean' => 'Очистка чата',
	'dateformat' => '<a target="_blank" href="http://php.net/manual/ru/function.date.php#refsect1-function.date-parameters">Формат даты</a>',
	'admfunc' => 'Административные функции',
	'allguests' => 'Все гости',
	'cleanmsgs' => 'Очистка сообщений',
	'room' => 'Общая комната',
	'selection' => 'Выбор',
	'cleannick' => 'По нику:',
	'clean' => 'Очистить',
	'kickchat' => '<b>Бан</b> (%d минут)',
	'kickreason' => 'Сообщение забаненому',
	'kickpurge' => 'Очистка сообщений',
	'kick' => 'Бан',
	'logoutinact' => 'Выход неактивного чата',
	'logout' => 'Выйти',
	'sessions' => 'Активные сессии',
	'view' => 'Просмотр',
	'filter' => 'Фильтр',
	'guestacc' => 'Изменить гостевой доступ',
	'guestallow' => 'Позволить',
	'guestwait' => 'Разрешить с гостевой',
	'adminallow' => 'Требовать одобрения модератора',
	'guestdisallow' => 'Только участники',
	'addsuguest' => 'Добавить заявителя',
	'register' => 'Зарегистрировать',
	'admmembers' => 'Участники',
	'memdel' => 'Удалить из базы данных',
	'memdeny' => 'Запретить доступ (!)',
	'memsuguest' => 'Набор к претенденту (G)',
	'memreg' => 'Установить участника',
	'memmod' => 'Набор модератора (M)',
	'memsumod' => 'Набор супермодератора (SM)',
	'memadm' => 'Набор администратора (A)',
	'change' => 'Изменить',
	'regguest' => 'Регистрация гостей',
	'regmem' => 'Регистрация новых участников',
	'sessact' => 'Активные сеансы',
	'sessnick' => 'Ник',
	'sesstimeout' => 'Время ожидания в',
	'sessua' => 'User-Agent',
	'fid' => 'Фильтр ID:',
	'match' => 'Совпадение',
	'replace' => 'Заменять',
	'allowpm' => 'Разрешить в личку',
	'regex' => 'Регулярное выражение',
	'apply' => 'Применить',
	'newfilter' => 'Новый фильтр:',
	'add' => 'Добавить',
	'noframes' => 'Этот чат использует <b>frames</b>. Пожалуйста, включите поддержку в Вашем браузере или используйте подходящий!',
	'delselmes' => 'Удалить выбранные сообщения',
	'staffnotes' => 'Служебные заметки',
	'adminnotes' => 'Примечания администратора',
	'notessaved' => 'Заметки сохранены!',
	'lastedited' => 'Последний раз редактировал %1$s %2$s',
	'savenotes' => 'Сохранить заметки',
	'waitingroom' => 'Гостевая',
	'waittext' => 'Добро пожаловать %1$s, Ваш логин задерживается, Вы можете получить доступ в чат через %2$d секунд.',
	'admwaittext' => 'Добро пожаловать %1$s, Ваш логин задерживается, Вы можете получить доступ в чат в ближайшее время, когда разрешит модератор.',
	'waitreload' => 'Если эта страница не отвечает, обновления каждые %d секунд, используйте кнопку ниже, чтобы загрузить его вручную!',
	'reload' => 'Перезагрузить',
	'rules' => 'Правила',
	'talkto' => 'Отправить',
	'toall' => 'Все в чате',
	'tomem' => 'Участники',
	'tostaff' => 'Служебные',
	'toadmin' => 'Администратор',
	'alsopurge' => 'Также очистить сообщения',
	'dellast' => 'Удалить последнее сообщение',
	'delall' => 'Удалить все сообщения',
	'switchsingle' => 'Переключитесь на одну линию',
	'switchmulti' => 'Переключитесь на мульти-линию',
	'help' => 'Помощь',
	'helpguest' => 'Все функции интуитивно понятны, просто используйте кнопки. В настройках вашего профиля вы можете настроить частоту обновления, цвет шрифта и желаемый размер окна входа.<br><u>Заметка:</u> Это чат, поэтому даже если вы ничего не пишете, то будете автоматически зарегистрированы через некоторое время..',
	'helpembed' => 'Если вы хотите встроить изображение в свой пост, просто положите [img] перед вашим URL-изображением. Пример: [img]http://example.com/images/file.jpg будет вставлять изображения в вашем посте.<br>',
	'helpmem' => 'Участники: У вас есть несколько вариантов настроек в вашем профиле. Можно настроить шрифт и изменить свой пароль в любое время.',
	'helpmod' => 'Модераторы: Обратите внимание кнопку администратора внизу. Это перенесет на страницу, где вы можете очистить комнату, забанить, просмотреть все активные сеансы и отключить гостевой доступ полностью, если необходимо.',
	'helpadm' => 'Администраторы: Вы способны регистрировать гостей, редактировать пользователей и регистрировать новые ники без их присутствия в комнате.',
	'profile' => 'Ваш профиль',
	'ignore' => 'Игнорировать',
	'unignore' => 'Больше не игнорировать',
	'refreshrate' => 'Частота обновления (5-150 секунд)',
	'fontcolour' => 'Цвет шрифта',
	'viewexample' => 'Посмотреть примеры',
	'bgcolour' => 'Фоновый цвет',
	'fontface' => 'Шрифт',
	'roomdefault' => 'По умолчанию',
	'bold' => 'Жирный',
	'italic' => 'Курсив',
	'fontexample' => 'Пример выбранного вами шрифта',
	'timestamps' => 'Показать отметки времени',
	'embed' => 'Вставить изображения (использует Cookies)',
	'incognito' => 'Режим инкогнито',
	'pbsize' => 'Размер окна сообщений',
	'nbsize' => 'Размер окна заметок',
	'width' => 'Ширина:',
	'height' => 'Высота:',
	'changepass' => 'Изменить пароль',
	'oldpass' => 'Старый пароль:',
	'newpass' => 'Новый пароль:',
	'confirmpass' => 'Подтверждение:',
	'savechanges' => 'Сохранить изменения',
	'reloadpb' => 'Перезагрузить почтовый ящик',
	'reloadmsgs' => 'Обновить',
	'chgprofile' => 'Профиль',
	'adminbtn' => 'Администратор',
	'admnotes' => 'Примечания администратора',
	'notes' => 'Примечания',
	'clone' => 'Клонировать',
	'randh' => 'Правила и помощь',
	'exit' => 'Выход',
	'bye' => 'Пока %s, заходите снова!',
	'colourtable' => 'Примеры цветов',
	'backtoprofile' => 'Вернуться к вашему профилю',
	'copy' => 'Копия:',
	'choosecol' => 'Гости выбирают цвет:',
	'randomcol' => 'Случайный цвет',
	'enter' => 'Войти в чат',
	'error' => 'Ошибка:',
	'members' => 'Зарегистрированные',
	'guests' => 'Гости',
	'approveguests' => '%d новые гости для одобрения',
	'allowchecked' => 'Разрешить проверять',
	'allowall' => 'Позволять всем',
	'denychecked' => 'Запретить проверять',
	'denyall' => 'Запретить всем',
	'denymessage' => 'Отправить сообщение с отказом:',
	'butallowdeny' => 'Отправить',
	'waitempty' => 'Нет больше запросов для одобрения.',
	'wrongcaptcha' => 'Неправильный код',
	'captchaexpire' => 'Защитный код уже используется или время истекло.',
	'noguests' => 'Извините, входят только зарегистрированные!',
	'curchat' => 'Сейчас %d разговор (ов) в комнате:',
	'cantreg' => 'Вы не можете зарегистрироваться %s',
	'alreadyreged' => '%s уже зарегистрирован.',
	'successreg' => '%s успешно зарегистрирован.',
	'cantchgstat' => 'Невозможно изменить статус %s',
	'succdel' => '%s успешно удален из базы данных.',
	'succchg' => 'Статус %s успешно изменен.',
	'wrongpass' => 'Неправильный пароль!',
	'wrongglobalpass' => 'Неправильный глобальный пароль!',
	'succprofile' => 'Ваш профиль был успешно сохранен.',
	'backtologin' => 'Вернуться на страницу входа.',
	'backtochat' => 'Вернуться в чат.',
	'Beige' => 'Бежевый',
	'Black' => 'Черный',
	'Blue' => 'Синий',
	'BlueViolet' => 'Фиолетово-синий',
	'Brown' => 'Коричневый',
	'Cyan' => 'Голубой',
	'DarkBlue' => 'Темно-синий',
	'DarkGreen' => 'Темно-зеленый',
	'DarkRed' => 'Темно-красный',
	'DarkViolet' => 'Темно-фиолетовый',
	'DeepSkyBlue' => 'Голубое небо',
	'Gold' => 'Золотой',
	'Grey' => 'Серый',
	'Green' => 'Зеленый',
	'HotPink' => 'Ярко-розовый',
	'Indigo' => 'Индиго',
	'LightBlue' => 'Светло-синий',
	'LightGreen' => 'Светло-зеленый',
	'LimeGreen' => 'Зеленый лайм',
	'Magenta' => 'Пурпурный',
	'Olive' => 'Оливковый',
	'Orange' => 'Оранжевый',
	'OrangeRed' => 'Оранжево-красный',
	'Purple' => 'Фиолетовый',
	'Red' => 'Красный',
	'RoyalBlue' => 'Королевский синий',
	'SeaGreen' => 'Морской зеленый',
	'Sienna' => 'Сиена',
	'Silver' => 'Серебряный',
	'Tan' => 'Загар',
	'Teal' => 'Чирок',
	'Violet' => 'Фиолетовый',
	'White' => 'Белый',
	'Yellow' => 'Желтый',
	'YellowGreen' => 'Желто-зеленый',
	'redirectto' => 'Перенаправление на:',
	'nonhttp' => 'Запрошенная ссылка не http:',
	'httpredir' => 'Если это не работает, попробуйте это:',
	'actions' => 'Действия',
	'sesip' => 'IP-адрес',
	'css' => 'CSS стили',
	'memberexpire' => 'Тайм-аут пользователей (минут)',
	'guestexpire' => 'Тайм-аут гостей (минут)',
	'kickpenalty' => 'Бан (минут)',
	'entrywait' => 'Время ожидания в гостевой (секунд)',
	'captchatime' => 'Тайм-аут Captcha (секунд)',
	'messageexpire' => 'Тайм-аут сообщения (минут)',
	'messagelimit' => 'Лимит сообщений (общих)',
	'maxmessage' => 'Максимальная длина сообщения',
	'confirm' => 'Вы уверены?',
	'yes' => 'Да',
	'no' => 'Нет',
	'colbg' => 'Фоновый цвет',
	'coltxt' => 'Цвет текста',
	'maxname' => 'Максимальная длина имени',
	'minpass' => 'Минимальная длина пароля',
	'defaultrefresh' => 'По умолчанию время перезагрузки сообщения (секунды)',
	'suguests' => 'Включить заявителей',
	'rulestxt' => 'Правила (html)',
	'imgembed' => 'Вставка изображений',
	'trackip' => 'Показать IP-сессию',
	'captchachars' => 'Символы, используемые в Captcha',
	'memkick' => 'Пользователи могут банить, если не присутствует модератор',
	'forceredirect' => 'Принудительное перенаправление',
	'redirect' => 'Пользовательский скрипт перенаправления',
	'backuprestore' => 'Бэкап и восстановление',
	'backup' => 'Бэкап',
	'restore' => 'Восстановление',
	'settings' => 'Настройки',
	'linkfilter' => 'Фильтрация ссылок'
);
?>

==> v1.22.1.tar.gz: le-chat-php/lang_ru.php <==
<?php
/*
* LE CHAT-PHP - a PHP Chat based on LE CHAT - Russian translation
*
* Copyright (C) 2015-2016 Daniel Winzen <d@winzen4.de>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//Native language name: Русский
$T=array(
	'nodb' => 'Нет соединения с базой данных!',
	'nodbsetup' => 'Нет соединения с базой данных, пожалуйста, создайте базу данных и измените сценарий, чтобы использовать правильную базу данных с заданными именем пользователя и паролем!',
	'changelang' => 'Изменить язык:',
	'expire' => 'Недействительная/с истекшим сроком сессия',
	'kicked' => 'Забанен!',
	'noconfirm' => 'Подтверждение пароля не совпадает!',
	'incorregex' => 'Неправильное регулярное выражение!',
	'bottom' => 'Вниз',
	'top' => 'Вверх',
	'choose' => '(выбрать)',
	'setup' => 'Установка чата',
	'init' => 'Начальная установка',
	'sulogin' => 'Вход для суперадминистратора',
	'sunick' => 'Ник суперадминистратора:',
	'supass' => 'Пароль суперадминистратора:',
	'suconfirm' => 'Подтверждение пароля:',
	'susuccess' => 'Успешно зарегистрирован!',
	'initbtn' => 'Инициализация чата',
	'initdbexist' => 'Таблицы базы данных уже существуют! Чтобы продолжить, вы должны сначала удалить эти таблицы вручную.',
	'initsuexist' => 'Суперадминистратор уже существует!',
	'initgosetup' => 'Перейти к странице установки',
	'captcha' => 'Captcha',
	'enabled' => 'Включен',
	'onlyguests' => 'Только для гостей',
	'disabled' => 'Выключен',
	'simple' => 'Простая',
	'moderate' => 'Умеренная',
	'extreme' => 'Сильная',
	'nick' => 'Ник:',
	'pass' => 'Пароль:',
	'globalloginpass' => 'Глобальный пароль:',
	'login' => 'Войти',
	'dbupdate' => 'База данных успешно обновлена!',
	'sysmessages' => 'Системные сообщения',
	'msgenter' => 'Вход',
	'msgexit' => 'Выход',
	'msgmemreg' => 'Зарегистрированные',
	'msgsureg' => 'Заявитель зарегистрирован',
	'msgkick' => 'Забаненые',
	'msgmultikick' => 'Многократно забаненые',
	'msgallkick' => 'Все забаненые',
	'msgclean' => 'Очистка чата',
	'dateformat' => '<a target="_blank" href="http://php.net/manual/ru/function.date.php#refsect1-function.date-parameters">Формат даты</a>',
	'admfunc' => 'Административные функции',
	'allguests' => 'Все гости',
	'cleanmsgs' => 'Очистка сообщений',
	'room' => 'Общая комната',
	'selection' => 'Выбор',
	'cleannick' => 'По нику:',
	'clean' => 'Очистить',
	'kickchat' => 'Бан (%d минут)',
	'kickreason' => 'Сообщение забаненому',
	'kickpurge' => 'Очистка сообщений',
	'kick' => 'Бан',
	'logoutinact' => 'Выход неактивного чата',
	'logout' => 'Выйти',
	'sessions' => 'Активные сессии',
	'view' => 'Просмотр',
	'filter' => 'Фильтр',
	'guestacc' => 'Изменить гостевой доступ',
	'guestallow' => 'Позволить',
	'guestwait' => 'Разрешить с гостевой',
	'adminallow' => 'Требовать одобрения модератора',
	'guestdisallow' => 'Только участники',
	'addsuguest' => 'Добавить заявителя',
	'register' => 'Зарегистрировать',
	'admmembers' => 'Участники',
	'memdel' => 'Удалить из базы данных',
	'memdeny' => 'Запретить доступ (!)',
	'memsuguest' => 'Набор к претенденту (G)',
	'memreg' => 'Установить участника',
	'memmod' => 'Набор модератора (M)',
	'memsumod' => 'Набор супермодератора (SM)',
	'memadm' => 'Набор администратора (A)',
	'change' => 'Изменить',
	'regguest' => 'Регистрация гостей',
	'regmem' => 'Регистрация новых участников',
	'sessact' => 'Активные сеансы',
	'sessnick' => 'Ник',
	'sesstimeout' => 'Время ожидания в',
	'sessua' => 'User-Agent',
	'fid' => 'Фильтр ID:',
	'match' => 'Совпадение',
	'replace' => 'Заменять',
	'allowpm' => 'Разрешить в личку',
	'regex' => 'Регулярное выражение',
	'apply' => 'Применить',
	'newfilter' => 'Новый фильтр:',
	'add' => 'Добавить',
	'noframes' => 'Этот чат использует <b>frames</b>. Пожалуйста, включите поддержку в Вашем браузере или используйте подходящий!',
	'delselmes' => 'Удалить выбранные сообщения',
	'staffnotes' => 'Служебные заметки',
	'adminnotes' => 'Примечания администратора',
	'notessaved' => 'Заметки сохранены!',
	'lastedited' => 'Последний раз редактировал %1$s %2$s',
	'savenotes' => 'Сохранить заметки',
	'waitingroom' => 'Гостевая',
	'waittext' => 'Добро пожаловать %1$s, Ваш логин задерживается, Вы можете получить доступ в чат через %2$d секунд.',
	'admwaittext' => 'Добро пожаловать %1$s, Ваш логин задерживается, Вы можете получить доступ в чат в ближайшее время, когда разрешит модератор.',
	'waitreload' => 'Если эта страница не отвечает, обновления каждые %d секунд, используйте кнопку ниже, чтобы загрузить его вручную!',
	'reload' => 'Перезагрузить',
	'rules' => 'Правила',
	'talkto' => 'Отправить',
	'toall' => 'Все в чате',
	'tomem' => 'Участники',
	'tostaff' => 'Служебные',
	'toadmin' => 'Администратор',
	'alsopurge' => 'Также очистить сообщения',
	'dellast' => 'Удалить последнее сообщение',
	'delall' => 'Удалить все сообщения',
	'switchsingle' => 'Переключитесь на одну линию',
	'switchmulti' => 'Переключитесь на мульти-линию',
	'help' => 'Помощь',
	'helpguest' => 'Все функции интуитивно понятны, просто используйте кнопки. В настройках вашего профиля вы можете настроить частоту обновления, цвет шрифта и желаемый размер окна входа.<br><u>Заметка:</u> Это чат, поэтому даже если вы ничего не пишете, то будете автоматически зарегистрированы через некоторое время..',
	'helpembed' => 'Если вы хотите встроить изображение в свой пост, просто положите [img] перед вашим URL-изображением. Пример: [img]http://example.com/images/file.jpg будет вставлять изображения в вашем посте.<br>',
	'helpmem' => 'Участники: У вас есть несколько вариантов настроек в вашем профиле. Можно настроить шрифт и изменить свой пароль в любое время.',
	'helpmod' => 'Модераторы: Обратите внимание кнопку администратора внизу. Это перенесет на страницу, где вы можете очистить комнату, забанить, просмотреть все активные сеансы и отключить гостевой доступ полностью, если необходимо.',
	'helpadm' => 'Администраторы: Вы способны регистрировать гостей, редактировать пользователей и регистрировать новые ники без их присутствия в комнате.',
	'profile' => 'Ваш профиль',
	'ignore' => 'Игнорировать',
	'unignore' => 'Больше не игнорировать',
	'refreshrate' => 'Частота обновления (5-150 секунд)',
	'fontcolour' => 'Цвет шрифта',
	'viewexample' => 'Посмотреть примеры',
	'bgcolour' => 'Фоновый цвет',
	'fontface' => 'Шрифт',
	'roomdefault' => 'По умолчанию',
	'bold' => 'Жирный',
	'italic' => 'Курсив',
	'fontexample' => 'Пример выбранного вами шрифта',
	'timestamps' => 'Показать отметки времени',
	'embed' => 'Вставить изображения',
	'incognito' => 'Режим инкогнито',
	'pbsize' => 'Размер окна сообщений',
	'nbsize' => 'Размер окна заметок',
	'width' => 'Ширина:',
	'height' => 'Высота:',
	'changepass' => 'Изменить пароль',
	'oldpass' => 'Старый пароль:',
	'newpass' => 'Новый пароль:',
	'confirmpass' => 'Подтверждение:',
	'savechanges' => 'Сохранить изменения',
	'reloadpb' => 'Перезагрузить почтовый ящик',
	'reloadmsgs' => 'Обновить',
	'chgprofile' => 'Профиль',
	'adminbtn' => 'Администратор',
	'admnotes' => 'Примечания администратора',
	'notes' => 'Примечания',
	'clone' => 'Клонировать',
	'randh' => 'Правила и помощь',
	'exit' => 'Выход',
	'bye' => 'Пока %s, заходите снова!',
	'colourtable' => 'Примеры цветов',
	'backtoprofile' => 'Вернуться к вашему профилю',
	'copy' => 'Копия:',
	'choosecol' => 'Гости выбирают цвет:',
	'randomcol' => 'Случайный цвет',
	'enter' => 'Войти в чат',
	'error' => 'Ошибка',
	'members' => 'Зарегистрированные',
	'guests' => 'Гости',
	'approveguests' => '%d новые гости для одобрения',
	'allowchecked' => 'Разрешить проверять',
	'allowall' => 'Позволять всем',
	'denychecked' => 'Запретить проверять',
	'denyall' => 'Запретить всем',
	'denymessage' => 'Отправить сообщение с отказом:',
	'butallowdeny' => 'Отправить',
	'waitempty' => 'Нет больше запросов для одобрения.',
	'wrongcaptcha' => 'Неправильный код',
	'captchaexpire' => 'Защитный код уже используется или время истекло.',
	'noguests' => 'Извините, входят только зарегистрированные!',
	'curchat' => 'Сейчас %d разговор (ов) в комнате:',
	'cantreg' => 'Вы не можете зарегистрироваться %s',
	'alreadyreged' => '%s уже зарегистрирован.',
	'successreg' => '%s успешно зарегистрирован.',
	'cantchgstat' => 'Невозможно изменить статус %s',
	'succdel' => '%s успешно удален из базы данных.',
	'succchg' => 'Статус %s успешно изменен.',
	'wrongpass' => 'Неправильный пароль!',
	'wrongglobalpass' => 'Неправильный глобальный пароль!',
	'succprofile' => 'Ваш профиль был успешно сохранен.',
	'backtologin' => 'Вернуться на страницу входа.',
	'backtochat' => 'Вернуться в чат.',
	'Beige' => 'Бежевый',
	'Black' => 'Черный',
	'Blue' => 'Синий',
	'BlueViolet' => 'Фиолетово-синий',
	'Brown' => 'Коричневый',
	'Cyan' => 'Голубой',
	'DarkBlue' => 'Темно-синий',
	'DarkGreen' => 'Темно-зеленый',
	'DarkRed' => 'Темно-красный',
	'DarkViolet' => 'Темно-фиолетовый',
	'DeepSkyBlue' => 'Голубое небо',
	'Gold' => 'Золотой',
	'Grey' => 'Серый',
	'Green' => 'Зеленый',
	'HotPink' => 'Ярко-розовый',
	'Indigo' => 'Индиго',
	'LightBlue' => 'Светло-синий',
	'LightGreen' => 'Светло-зеленый',
	'LimeGreen' => 'Зеленый лайм',
	'Magenta' => 'Пурпурный',
	'Olive' => 'Оливковый',
	'Orange' => 'Оранжевый',
	'OrangeRed' => 'Оранжево-красный',
	'Purple' => 'Фиолетовый',
	'Red' => 'Красный',
	'RoyalBlue' => 'Королевский синий',
	'SeaGreen' => 'Морской зеленый',
	'Sienna' => 'Сиена',
	'Silver' => 'Серебряный',
	'Tan' => 'Загар',
	'Teal' => 'Чирок',
	'Violet' => 'Фиолетовый',
	'White' => 'Белый',
	'Yellow' => 'Желтый',
	'YellowGreen' => 'Желто-зеленый',
	'redirectto' => 'Перенаправление на:',
	'nonhttp' => 'Запрошенная ссылка не http:',
	'httpredir' => 'Если это не работает, попробуйте это:',
	'actions' => 'Действия',
	'sesip' => 'IP-адрес',
	'css' => 'CSS стили',
	'memberexpire' => 'Тайм-аут пользователей (минут)',
	'guestexpire' => 'Тайм-аут гостей (минут)',
	'kickpenalty' => 'Бан (минут)',
	'entrywait' => 'Время ожидания в гостевой (секунд)',
	'captchatime' => 'Тайм-аут Captcha (секунд)',
	'messageexpire' => 'Тайм-аут сообщения (минут)',
	'messagelimit' => 'Лимит сообщений (общих)',
	'maxmessage' => 'Максимальная длина сообщения',
	'confirm' => 'Вы уверены?',
	'yes' => 'Да',
	'no' => 'Нет',
	'colbg' => 'Фоновый цвет',
	'coltxt' => 'Цвет текста',
	'maxname' => 'Максимальная длина имени',
	'minpass' => 'Минимальная длина пароля',
	'defaultrefresh' => 'По умолчанию время перезагрузки сообщения (секунды)',
	'suguests' => 'Включить заявителей',
	'rulestxt' => 'Правила (html)',
	'imgembed' => 'Вставка изображений',
	'trackip' => 'Показать IP-сессию',
	'captchachars' => 'Символы, используемые в Captcha',
	'memkick' => 'Пользователи могут банить, если не присутствует модератор',
	'forceredirect' => 'Принудительное перенаправление',
	'redirect' => 'Пользовательский скрипт перенаправления',
	'backuprestore' => 'Бэкап и восстановление',
	'backup' => 'Бэкап',
	'restore' => 'Восстановление',
	'settings' => 'Настройки',
	'linkfilter' => 'Фильтрация ссылок'
);
?>
